@@ -11,6 +11,7 @@ from metrics_layer.core.exceptions import (
 
 from .base import MetricsLayerBase
 from .week_start_day_types import WeekStartDayTypes
+from .view import View
 
 if TYPE_CHECKING:
     from metrics_layer.core.model.project import Project
@@ -44,6 +45,9 @@ class AccessGrant(MetricsLayerBase):
                     name_str = f" {definition.get('name')}"
                 raise QueryError(f"Access Grant{name_str} missing required key {k}")
 
+    def id(self):
+        return self.name
+
     def _error(self, element, error):
         return self.model._error(element, error)
 
@@ -102,8 +106,10 @@ class Model(MetricsLayerBase):
         "week_start_day",
         "timezone",
         "default_convert_tz",
+        "fiscal_month_offset",
         "access_grants",
         "mappings",
+        "required_access_grants",
     ]
     internal_properties = ["_file_path"]
 
@@ -122,6 +128,15 @@ class Model(MetricsLayerBase):
                     name_str = f" in the model {definition.get('name')}"
                 raise QueryError(f"Model missing required key {k}{name_str}")
 
+    def id(self):
+        return self.name
+
+    @property
+    def fiscal_month_offset(self):
+        if "fiscal_month_offset" in self._definition:
+            return self._definition["fiscal_month_offset"]
+        return 0
+
     @property
     def access_grants(self):
         if "access_grants" in self._definition:
@@ -129,7 +144,7 @@ class Model(MetricsLayerBase):
                 raise QueryError(
                     f"The access_grants property, {self._definition['access_grants']} must be a list"
                 )
-            elif all([not isinstance(grant, dict) for grant in self._definition["access_grants"]]):
+            elif not all([isinstance(grant, dict) for grant in self._definition["access_grants"]]):
                 raise QueryError(f"All access_grants in the access_grants property must be dictionaries")
             return self._definition["access_grants"]
         return []
@@ -186,6 +201,18 @@ class Model(MetricsLayerBase):
                 )
             )
 
+        if "fiscal_month_offset" in self._definition:
+            if not isinstance(self.fiscal_month_offset, int):
+                errors.append(
+                    self._error(
+                        self.fiscal_month_offset,
+                        (
+                            f"The fiscal_month_offset property, {self.fiscal_month_offset} must be an integer"
+                            f" in the model {self.name}"
+                        ),
+                    )
+                )
+
         if "week_start_day" in self._definition:
             if str(self.week_start_day) not in WeekStartDayTypes.options:
                 errors.append(
@@ -236,6 +263,15 @@ class Model(MetricsLayerBase):
             errors.append(
                 self._error(self._definition["access_grants"], str(e) + f" in the model {self.name}")
             )
+        errors.extend(
+            View.collect_required_access_grant_errors(
+                self._definition,
+                self.project,
+                f"in model {self.name}",
+                f"in model {self.name}",
+                error_func=self._error,
+            )
+        )
         valid_mappings_properties = ["fields", "group_label", "description", "link", "label"]
         try:
             mappings = self.mappings
