@@ -51,7 +51,7 @@ class ProjectLoader:
         else:
             raise TypeError(f"Unknown repo type: {repo_type}, valid types are 'metrics_layer', 'metricflow'")
 
-        models, views, dashboards, topics = reader.load()
+        models, views, dashboards, topics, errors = reader.load()
         commit_hash = (
             self.repo.git_repo.head.commit.hexsha
             if isinstance(self.repo, GithubRepo) and self.repo.git_repo is not None
@@ -67,6 +67,7 @@ class ProjectLoader:
             connection_lookup={c.name: c.type for c in self._connections},
             manifest=Manifest(reader.manifest),
             commit_hash=commit_hash,
+            conversion_errors=errors,
         )
         return project
 
